<?php

namespace App\Http\Controllers\Admin;

use App\Models\Car;
use App\Models\Article;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;

class ArticlesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $articles = Article::all();
        return view('admin.articles.index',compact('articles'));
    }

    public function create()
    {
        return view('admin.articles.create');
    }

    public function edit($id)
    {
        $data['article'] = Article::findOrFail($id);
        return view('admin.articles.edit', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'title' => ['required','string','max:255'],
            'seo_title' => ['sometimes','nullable','string','max:255'],
            'slug' => ['sometimes','nullable','max:255','unique:articles,slug'],
            'description' => ['sometimes','nullable'],
            'seo_description' => ['sometimes','nullable','string'],
            'status' => ['required','in:active,inactive'],
            'featured_image' => ['required','image'],
            'promo_video' => ['sometimes','nullable','url'],
        ]);

        $filename = Car::generate_photo_name(Str::slug($request->title));
        $request->file('featured_image')->storeAs('/',$filename,'articles');

        $locale = app()->getLocale();

        $article = new Article;
        $article->setTranslation('title', $locale, $request->title);
        $article->setTranslation('seo_title', $locale, ($request->seo_title ? $request->seo_title : $request->title));
        $article->setTranslation('slug', $locale, ($request->slug ? Str::slug($request->slug) : Str::slug($request->title)));
        $article->setTranslation('description', $locale, $request->description);
        $article->setTranslation('seo_description', $locale, $request->seo_description);
        $article->setTranslation('seo_keywords', $locale, $request->seo_keywords);
        $article->status = $request->status;
        $article->promo_video = $request->promo_video;
        $article->featured_image = $filename;

        $article->save();
        return response()->json(['msg'=>'success','url' => route('admin.articles.index')]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $locale = app()->getLocale();
        $article = Article::findOrFail($id);
        $article->setTranslation('title', $locale, $request->title);
        $article->setTranslation('seo_title', $locale, ($request->seo_title ? $request->seo_title : $request->title));
        $article->setTranslation('slug', $locale, ($request->slug ? Str::slug($request->slug) : Str::slug($request->title)));
        $article->setTranslation('description', $locale, $request->description);
        $article->setTranslation('seo_description', $locale, $request->seo_description);
        $article->setTranslation('seo_keywords', $locale, $request->seo_keywords);
        $article->status = $request->status;

        if ($request->hasFile('featured_image')) {
            $oldFilename = $article->featured_image;
            $filename = 'location-rent-voiture-a-marrakech-louer-voiture-morocco-' . Str::slug($request->title) . '-review-marrakesh-cars-rental-maroc-marrakech-luxelocation.ma-' . time() . '.jpg';
            $request->file('featured_image')->storeAs('/', $filename, 'articles');
            $article->featured_image = $filename;
            if (Storage::disk('articles')->exists('/' . $oldFilename)) {
                Storage::disk('articles')->delete('/' . $oldFilename);
            }
        }

        $article->promo_video = $request->promo_video;

        $article->save();
        return response()->json(['msg'=>'success','url' => route('admin.articles.index')]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $article = Article::findOrFail($id);
        if(Storage::disk('articles')->exists('/'.$article->featured_image)){
            Storage::disk('articles')->delete('/'.$article->featured_image);
        }
        $article->delete();
        return response()->json(['msg'=>'success']);
    }
}
