<?php

namespace App\Http\Controllers\Admin;

use App\Models\Car;
use App\Models\Location;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;

class LocationsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $locations = Location::all();
        return view('admin.locations',compact('locations'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => ['string','required','min:3'],
            'photo' => ['image','sometimes'],
        ]);

        $filename = Car::generate_photo_name(Str::slug($data['name']));
        $request->file('photo')->storeAs('/',$filename,'locations');

        $location = new Location;
        $location->setTranslation('name',app()->getLocale(),$data['name']);
        $location->photo = $filename;
        $location->save();
        return response()->json(['msg'=>'success']);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $request->validate([
            'name' => ['string','required','min:3'],
            'photo' => ['image','sometimes'],
        ]);
        
        $location = Location::findOrFail($id);

        if($request->hasFile('photo')){
            $filename = Car::generate_photo_name(Str::slug($data['name']));
            $request->file('photo')->storeAs('/',$filename,'locations');
            if(Storage::disk('locations')->exists('/'.$location->photo)){
                Storage::disk('locations')->delete('/'.$location->photo);
            }
            $location->photo = $filename;
        }

        $location->setTranslation('name',app()->getLocale(),$data['name']);
        $location->save();
        return response()->json(['msg'=>'success']);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $location = Location::findOrFail($id);
        if(Storage::disk('locations')->exists('/'.$location->photo)){
            Storage::disk('locations')->delete('/'.$location->photo);
        }
        $location->delete();
        return response()->json(['msg'=>'success']);
    }
}
