<?php

namespace App\Http\Controllers\Admin;

use App\Models\Car;
use Illuminate\Support\Str;
use App\Models\PropertyType;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;

class PropertyTypesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $types = PropertyType::all();
        return view('admin.property-types',compact('types'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => ['string','required','min:3'],
            'photo' => ['image','sometimes'],
        ]);

        $filename = Car::generate_photo_name(Str::slug($data['name']));
        $request->file('photo')->storeAs('/',$filename,'types');

        $propType = new PropertyType;
        $propType->setTranslation('name',app()->getLocale(),$data['name']);
        $propType->photo = $filename;
        $propType->save();
        return response()->json(['msg'=>'success']);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $request->validate([
            'name' => ['string','required','min:3'],
            'photo' => ['image','sometimes'],
        ]);

        $propType = PropertyType::findOrFail($id);
        if($request->hasFile('photo')){
            $filename = Car::generate_photo_name(Str::slug($data['name']));
            $request->file('photo')->storeAs('/',$filename,'types');
            if(Storage::disk('types')->exists('/'.$propType->photo)){
                Storage::disk('types')->delete('/'.$propType->photo);
            }
            $propType->photo = $filename;
        }
        $propType->setTranslation('name',app()->getLocale(),$data['name']);
        $propType->save();
        return response()->json(['msg'=>'success']);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $propType = PropertyType::findOrFail($id);
        if(Storage::disk('types')->exists('/'.$propType->photo)){
            Storage::disk('types')->delete('/'.$propType->photo);
        }
        $propType->delete();
        return response()->json(['msg'=>'success']);
    }
}
