<?php

namespace App\Http\Controllers\Admin;

use App\Models\Car;
use App\Models\Theme;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;

class ThemesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $themes = Theme::all();
        return view('admin.themes',compact('themes'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => ['string','required','min:3'],
            'photo' => ['image','sometimes'],
        ]);

        $filename = Car::generate_photo_name(Str::slug($data['name']));
        $request->file('photo')->storeAs('/',$filename,'themes');

        $theme = new Theme;
        $theme->setTranslation('name',app()->getLocale(),$data['name']);
        $theme->photo = $filename;
        $theme->save();
        return response()->json(['msg'=>'success']);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = $request->validate([
            'name' => ['string','required','min:3'],
        ]);

        $theme = Theme::findOrFail($id);
        if($request->hasFile('photo')){
            $filename = Car::generate_photo_name(Str::slug($data['name']));
            $request->file('photo')->storeAs('/',$filename,'themes');
            if(Storage::disk('themes')->exists('/'.$theme->photo)){
                Storage::disk('themes')->delete('/'.$theme->photo);
            }
            $theme->photo = $filename;
        }
        $theme->setTranslation('name',app()->getLocale(),$data['name']);
        $theme->save();
        return response()->json(['msg'=>'success']);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $theme = Theme::findOrFail($id);
        if(Storage::disk('types')->exists('/'.$theme->photo)){
            Storage::disk('types')->delete('/'.$theme->photo);
        }
        $theme->delete();
        return response()->json(['msg'=>'success']);
    }
}
