<?php

namespace App\Http\Controllers;

use App\Models\Agent;
use App\Models\Provider;
use Illuminate\Http\Request;
use Illuminate\Validation\Rules;
use Illuminate\Support\Facades\Hash;

class AgentsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $agents = Agent::with('provider')->get();
        $providers = Provider::get();
        return view('admin.agents',compact('agents','providers'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:agents'],
            'phone' => ['required', 'string', 'max:25'],
            'address' => ['sometimes', 'nullable', 'string', 'max:255'],
            'status' => ['required', 'in:active,inactive'],
            'gender' => ['required', 'in:male,female'],
            'provider_id' => ['sometimes', 'nullable'],
            'password' => ['required', 'confirmed', Rules\Password::defaults()],
        ]);

        Agent::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => Hash::make($request->password),
            'phone' => $request->phone,
            'address' => $request->address,
            'status' => $request->status,
            'gender' => $request->gender,
            'provider_id' => $request->provider_id
        ]);
        return response()->json(['msg'=>'success']);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:agents,email,'.$id],
            'phone' => ['required', 'string', 'max:25'],
            'address' => ['sometimes', 'nullable', 'string', 'max:255'],
            'status' => ['required', 'in:active,inactive'],
            'gender' => ['required', 'nullable', 'in:male,female'],
            'provider_id' => ['sometimes', 'nullable'],
            'password' => ['sometimes', 'nullable', 'confirmed', Rules\Password::defaults()],
        ]);

        $data = [
            'name' => $request->name,
            'email' => $request->email,
            'phone' => $request->phone,
            'address' => $request->address,
            'status' => $request->status,
            'gender' => $request->gender,
            'provider_id' => $request->provider_id
        ];

        if($request->password){
            $data['password'] = Hash::make($request->password);
        }

        Agent::findOrFail($id)->update($data);
        return response()->json(['msg'=>'success']);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Agent::findOrFail($id)->delete();
        return response()->json(['msg'=>'success']);
    }
}
