<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\LoginRequest;
use App\Providers\RouteServiceProvider;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AuthenticatedSessionController extends Controller
{

    protected $guard = 'web';

    public function __construct(Request $request)
    {
        $locale = app()->getLocale() . '/';
        if ($request->is($locale . 'admin/*')) {
            $this->guard = 'admin';
        } elseif ($request->is($locale . 'provider/*')) {
            $this->guard = 'provider';
        } elseif ($request->is($locale . 'agent/*')) {
            $this->guard = 'agent';
        }
    }

    /**
     * Display the login view.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        if($this->guard == 'admin'){
            return view('admin.login');
        }elseif($this->guard == 'agent'){
            return view('agent.login');
        }elseif($this->guard == 'provider'){
            return view('provider.login');
        }
        return view('auth.login');
    }

    /**
     * Handle an incoming authentication request.
     *
     * @param  \App\Http\Requests\Auth\LoginRequest  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(LoginRequest $request)
    {
        $request->authenticate($this->guard);

        $request->session()->regenerate();

        $route = RouteServiceProvider::HOME;

        if($this->guard == 'admin'){
            $route = RouteServiceProvider::ADMIN;
        }elseif($this->guard == 'agent'){
            $route = RouteServiceProvider::AGENT;
        }elseif($this->guard == 'provider'){
            $route = RouteServiceProvider::PROVIDER;
        }

        return redirect()->intended($route);
    }

    /**
     * Destroy an authenticated session.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy(Request $request)
    {
        Auth::guard($this->guard)->logout();

        $request->session()->invalidate();

        $request->session()->regenerateToken();

        return redirect('/');
    }
}
