<?php

namespace App\Http\Controllers\Front;

use App\Models\Car;
use App\Models\Reservation;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use App\Http\Controllers\Controller;

class CarsController extends Controller
{
    public function index()
    {
        $data['properties'] = Car::where('status', 'active')->with('currency')->paginate(2);
        return view('cars', $data);
    }

    public function details($slug, $car)
    {
        $data['property'] = Car::where('status', 'active')->with(['currency', 'photos'])->findOrFail($car);
        return view('car', $data);
    }

    public function reserve(Request $request, $car)
    {
        $data = $request->validate([
            'firstname' => ['string', 'required', 'min:2'],
            'lastname' => ['string', 'required', 'min:2'],
            'email' => ['email', 'required'],
            'phone' => ['string', 'required', 'min:7'],
            'arrival_date' => 'required|date',
            'arrival_hour' => 'required|date_format:H:i',
            'departure_date' => 'required|date',
            'departure_hour' => 'required|date_format:H:i',
        ]);

        $data['arrival'] = Carbon::parse($request->input('arrival_date') . ' ' . $request->input('arrival_hour'));
        $data['departure'] = Carbon::parse($request->input('departure_date') . ' ' . $request->input('departure_hour'));

        $interval = $data['arrival']->diff($data['departure']);
        $d = $interval->format('%a');
        $numberOfDays = $d > 0 ? $d : 1;

        $car = Car::where('status', 'active')->findOrFail($car);

        $last_reservation_id = Reservation::latest()->limit(1)->pluck('id');

        $last_reservation_id = $last_reservation_id ? $last_reservation_id[0] : 0;

        Reservation::create(['order_id' => date('Ym') . str_pad($last_reservation_id, 4, '0', STR_PAD_LEFT), 'reservable_type' => 'App\Models\Car', 'reservable_id' => $car->id, 'firstname' => $data['firstname'], 'lastname' => $data['lastname'], 'email' => $data['email'], 'phone' => $data['phone'], 'arrival' => $data['arrival'], 'departure' => $data['departure'], 'total' => $car->price * $numberOfDays, 'currency_id' => $car->currency_id]);

        return response()->json(['msg' => 'success']);
    }
}
