<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Spatie\Translatable\HasTranslations;

class Car extends Model
{
    use HasFactory, HasTranslations;
    public $translatable = ['title','description','slug','seo_title','seo_description','seo_keywords'];

    protected $guarded = [];

    protected $casts = [
        'price_by_period' => 'array',
    ];

    public static function generate_photo_name($slug){
        $keywords = [
            'location-voitures-a-marrakech',
            'car-rental-marrakesh',
            'rent-voiture-marrakesh',
            'location-auto-morocco',
            'louer-voiture-marrakech',
            'rental-cars-marrakech',
            'voitures-de-location-marrakech',
            'vehicle-rental',
        ];
        $slug = implode('-', $keywords) . '-' . $slug . '-' . time() . '.jpg';
        return $slug;
    }

    public function themes(){
        return $this->morphToMany(Theme::class,'tpropertiable','tpropertiables');
    }

    public function amenities(){
        return $this->morphToMany(Amenity::class,'apropertiable','apropertiables');
    }

    public function photos(){
        return $this->morphMany(Photo::class,'photoable');
    }

    public function reservations(){
        return $this->morphToMany(User::class,'reservable','reservations');
    }

    public function favorites(){
        return $this->morphToMany(User::class,'favorable','favorites');
    }

    public function reviews(){
        return $this->morphToMany(User::class,'reviewable','reviews');
    }

    public function currency(){
        return $this->belongsTo(Currency::class);
    }

    public function location(){
        return $this->belongsTo(Location::class);
    }
}
