<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateCarsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('cars', function (Blueprint $table) {
            $table->id();
            $table->text('title');
            $table->text('seo_title');
            $table->longText('description');
            $table->text('seo_description');
            $table->text('seo_keywords');
            $table->string('slug',1000)->unique();
            $table->float('price');
            $table->float('max_price')->nullable();
            $table->json('price_by_period')->nullable();
            $table->foreignId('currency_id')->constrained('currencies');
            $table->enum('duration_unit',['day','week','month','year']);
            $table->tinyInteger('min_period')->default(1);
            //
            $table->tinyInteger('model')->nullable();
            $table->integer('kilometrage')->nullable();
            $table->enum('carburant',['essence','diesel'])->default('diesel');
            $table->tinyInteger('passengers')->default(4);
            $table->tinyInteger('doors')->default(4);
            $table->tinyInteger('baggages')->default(1)->comment('count of Luggages (bags)');
            $table->enum('gear_shift',['manual','auto'])->default('manual');
            //
            $table->foreignId('location_id')->constrained('locations');
            $table->foreignId('type_id')->constrained('property_types');
            $table->string('featured_image',1000);
            $table->string('promo_video')->nullable();
            $table->enum('status',['active','inactive']);
            $table->boolean('new')->default(false);
            $table->boolean('featured')->default(false);
            $table->foreignId('provider_id')->nullable()->constrained('providers')->nullOnDelete();
            $table->foreignId('agent_id')->nullable()->constrained('agents')->nullOnDelete();
            $table->string('fetched_url')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('cars');
    }
}
