@extends('admin.layouts.master')

@push('css')
<!-- Datatables CSS -->
<link rel="stylesheet" href="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.css' }}">
@endpush

@push('js')
<!-- Datatables JS -->
<script src="{{ asset('ad') . '/assets/plugins/datatables/jquery.dataTables.min.js' }}"></script>
<script src="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.js' }}"></script>
<script>
    setActiveMenuItem('amenities');
</script>
@endpush

@section('content')
    <!-- Page Header -->
    <div class="page-header">
        <div class="row">
            <div class="col">
                <h3 class="page-title">Amenities</h3>
                <ul class="breadcrumb">
                    <li class="breadcrumb-item"><a href="index.html">Dashboard</a></li>
                    <li class="breadcrumb-item active">Amenities</li>
                </ul>
            </div>
            <div class="col-auto">
                <button type="button" class="btn btn-primary me-1" data-bs-toggle="modal" data-bs-target="#addModal">
                    <i class="fas fa-plus"></i>
                </button>

                <!-- Modal -->
                <div class="modal fade" id="addModal" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="addModalLabel" aria-hidden="true">
                    <div class="modal-dialog">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h5 class="modal-title" id="addModalLabel">New Amenity</h5>
                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                            </div>
                            <div class="modal-body">
                                <form class="ajax-form px-3" action="{{ route('admin.amenities.store') }}" method="POST">
                                    @csrf
                                    <div class="mb-3">
                                        <label for="name" class="form-label">Name</label>
                                        <input class="form-control" type="text" name="name" required="" placeholder="type amenity name ..">
                                    </div>

                                    <div class="mt-3 text-end">
                                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                        <button class="btn btn-primary" type="submit">Create</button>
                                    </div>

                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- /Page Header -->
    
    <div class="row">
        <div class="col-sm-12">
            
            <div class="card card-table">
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-center table-hover datatable">
                            <thead class="thead-light">
                                <tr>
                                    <th>ID</th>
                                    <th>Name</th>
                                    <th class="text-end">Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($amenities as $amenity)
                                    <tr>
                                        <td>{{ $amenity->id }}</td>
                                        <td>{{ $amenity->name }}</td>
                                        <td class="text-end">
                                            <button class="btn btn-sm btn-white text-success me-2" data-bs-toggle="modal" data-bs-target="#modal{{ $amenity->id }}"><i class="far fa-edit me-1"></i> Edit</button>
                                            <div class="modal fade" id="modal{{ $amenity->id }}" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="modal{{ $amenity->id }}Label" aria-hidden="true">
                                                <div class="modal-dialog">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title" id="modal{{ $amenity->id }}Label">Edit Location</h5>
                                                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body text-start">
                                                            <form class="ajax-form px-3" action="{{ route('admin.amenities.update',['amenity'=>$amenity->id]) }}" method="POST">
                                                                @csrf
                                                                @method('PUT')
                                                                <div class="mb-3">
                                                                    <label for="name" class="form-label">Name</label>
                                                                    <input class="form-control" type="text" name="name" value="{{ $amenity->name }}" required="" placeholder="type amenity name ..">
                                                                </div>
                            
                                                                <div class="mt-3 text-end">
                                                                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                                                    <button class="btn btn-primary" type="submit">Save</button>
                                                                </div>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <button class="btn btn-sm btn-white text-danger me-2" data-bs-toggle="modal" data-bs-target="#dmodal{{ $amenity->id }}"><i class="far fa-trash-alt me-1"></i>Delete</button>
                                            <div class="modal fade" id="dmodal{{ $amenity->id }}" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="dmodal{{ $amenity->id }}Label" aria-hidden="true">
                                                <div class="modal-dialog">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title" id="dmodal{{ $amenity->id }}Label">Confirm Deletion</h5>
                                                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body text-start">
                                                            <form class="ajax-form px-3" action="{{ route('admin.amenities.destroy',['amenity'=>$amenity->id]) }}" method="POST">
                                                                @csrf
                                                                @method('DELETE')
                                                                <div class="mb-3">
                                                                    <label for="name" class="form-label">Name</label>
                                                                    <input class="form-control" disabled type="text" name="name" value="{{ $amenity->name }}" required="" placeholder="type amenity name ..">
                                                                </div>
                            
                                                                <div class="mt-3 text-end">
                                                                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                                                    <button class="btn btn-danger" type="submit">Delete</button>
                                                                </div>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection