@extends('admin.layouts.master')

@push('css')
<!-- Datatables CSS -->
<link rel="stylesheet" href="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.css' }}">
@endpush

@push('js')
<!-- Datatables JS -->
<script src="{{ asset('ad') . '/assets/plugins/datatables/jquery.dataTables.min.js' }}"></script>
<script src="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.js' }}"></script>
<script>
    setActiveMenuItem('cars');
</script>
@endpush

@section('content')
    <!-- Page Header -->
    <div class="page-header">
        <div class="row">
            <div class="col">
                <h3 class="page-title">Cars</h3>
                <ul class="breadcrumb">
                    <li class="breadcrumb-item"><a href="index.html">Dashboard</a></li>
                    <li class="breadcrumb-item active">Cars</li>
                </ul>
            </div>
            <div class="col-auto">
                <a class="btn btn-primary me-1" href="{{ route('admin.cars.create') }}">
                    <i class="fas fa-plus"></i>
                </a>
            </div>
        </div>
    </div>
    <!-- /Page Header -->
    
    <div class="row">
        <div class="col-sm-12">
            
            <div class="card card-table">
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-center table-hover datatable">
                            <thead class="thead-light">
                                <tr>
                                    <th data-searchable="true">ID</th>
                                    <th data-searchable="true">Title</th>
                                    <th data-filterselect="true">Status</th>
                                    <th data-searchable="true">Price / Unit</th>
                                    <th data-filterselect="true">Price Vars</th>
                                    <th data-searchable="true">Location</th>
                                    <th data-searchable="true">Created At</th>
                                    <th class="text-end">Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($cars as $car)
                                    <tr>
                                        <td>{{ $car->id }}</td>
                                        <td>{{ $car->title }}</td>
                                        <td>
                                            <span class="badge badge-pill bg-{{ $car->status == 'active' ? 'success' : 'danger' }}-light">{{ $car->status }}</span>
                                        </td>
                                        <td>{{ $car->price . ' ' . $car->currency->symbol . ' / ' . $car->duration_unit }}</td>
                                        <td>
                                            <span class="badge badge-pill bg-{{ $car->price_by_period ? 'success' : 'danger' }}-light">{{ $car->price_by_period ? 'Yes' : 'No' }}</span>
                                        </td>
                                        <td>{{ $car->location->name }}</td>
                                        <td>{{ $car->created_at->diffForHumans() }}</td>
                                        <td class="text-end">
                                            <a class="btn btn-sm btn-white text-warning me-1" href="{{ route('admin.cars.preview',['car'=>$car->id]) }}"><i class="fa fa-calendar-alt"></i></a>
                                            <a class="btn btn-sm btn-white text-info me-1" href="{{ route('admin.cars.preview',['car'=>$car->id]) }}"><i class="fa fa-eye"></i></a>
                                            <a class="btn btn-sm btn-white text-primary me-1" href="{{ route('admin.cars.photos',['car'=>$car->id]) }}"><i class="fa fa-camera"></i></a>
                                            <a class="btn btn-sm btn-white text-success me-1" href="{{ route('admin.cars.edit',['car'=>$car->id]) }}"><i class="far fa-edit"></i></a>
                                            <button class="btn btn-sm btn-white text-danger me-1" data-bs-toggle="modal" data-bs-target="#dmodal{{ $car->id }}"><i class="far fa-trash-alt"></i></button>
                                            <div class="modal fade" id="dmodal{{ $car->id }}" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="dmodal{{ $car->id }}Label" aria-hidden="true">
                                                <div class="modal-dialog">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title" id="dmodal{{ $car->id }}Label">Confirm Deletion</h5>
                                                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body text-start">
                                                            <form class="ajax-form px-3" action="{{ route('admin.cars.destroy',['car'=>$car->id]) }}" method="POST">
                                                                @csrf
                                                                @method('DELETE')
                                                                <div class="mb-3">
                                                                    <label for="name" class="form-label">Name</label>
                                                                    <input class="form-control" disabled type="text" name="name" value="{{ $car->title }}" required="" placeholder="type car name ..">
                                                                </div>
                            
                                                                <div class="mt-3 text-end">
                                                                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                                                    <button class="btn btn-danger" type="submit">Delete</button>
                                                                </div>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection