@extends('admin.layouts.master')

@push('css')
    <!-- Datatables CSS -->
    <link rel="stylesheet" href="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.css' }}">
@endpush

@push('js')
    <!-- Datatables JS -->
    <script src="{{ asset('ad') . '/assets/plugins/datatables/jquery.dataTables.min.js' }}"></script>
    <script src="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.js' }}"></script>
    <script>
        setActiveMenuItem('favorites');
    </script>
@endpush

@section('content')
    <!-- Page Header -->
    <div class="page-header">
        <div class="row">
            <div class="col">
                <h3 class="page-title">Favorites</h3>
                <ul class="breadcrumb">
                    <li class="breadcrumb-item"><a href="index.html">Dashboard</a></li>
                    <li class="breadcrumb-item active">Favorites</li>
                </ul>
            </div>
        </div>
    </div>
    <!-- /Page Header -->

    <div class="row">
        <div class="col-sm-12">

            <div class="card card-table">
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-center table-hover datatable">
                            <thead class="thead-light">
                                <tr>
                                    <th data-searchable="true">ID</th>
                                    <th data-searchable="true">Property name</th>
                                    <th data-searchable="true">User</th>
                                    <th data-searchable="true">Email</th>
                                    <th data-searchable="true">Phone</th>
                                    <th data-searchable="true">Added At</th>
                                    <th class="text-end">Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($favorites as $favorite)
                                    <tr>
                                        <td>{{ $favorite->id }}</td>
                                        <td><a href="{{ route('admin.cars.preview', ['car' => $favorite->car->id]) }}"
                                                target="_blank">{{ $favorite->car->title }}</a></td>
                                        <td>
                                            {{ ($favorite->user->gender == 'male' ? 'Mr.' : 'Mme.') . ' ' . $favorite->user->firstname . ' ' . $favorite->user->laststname }}
                                        </td>
                                        <td><a
                                                href="mailto:{{ $favorite->user->email }}">{{ $favorite->user->email }}</a>
                                        </td>
                                        <td>{{ $favorite->user->phone }}</td>
                                        <td>{{ $favorite->created_at->diffForHumans() }}</td>
                                        <td class="text-end">
                                            <button class="btn btn-sm btn-white text-danger me-2" data-bs-toggle="modal"
                                                data-bs-target="#dmodal{{ $favorite->id }}"><i
                                                    class="far fa-trash-alt me-1"></i>Delete</button>
                                            <div class="modal fade" id="dmodal{{ $favorite->id }}"
                                                data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
                                                aria-labelledby="dmodal{{ $favorite->id }}Label" aria-hidden="true">
                                                <div class="modal-dialog">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title" id="dmodal{{ $favorite->id }}Label">
                                                                Confirm Deletion</h5>
                                                            <button type="button" class="btn-close"
                                                                data-bs-dismiss="modal" aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body text-start">
                                                            <form class="ajax-form px-3"
                                                                action="{{ route('admin.favorites.destroy', ['favorite' => $favorite->id]) }}"
                                                                method="POST">
                                                                @csrf
                                                                @method('DELETE')
                                                                <div class="mb-3">
                                                                    <label for="name" class="form-label">Favorite ID</label>
                                                                    <input class="form-control" disabled type="text"
                                                                        name="name" value="{{ $favorite->id }}"
                                                                        required=""
                                                                        placeholder="type favorite name ..">
                                                                </div>

                                                                <div class="mt-3 text-end">
                                                                    <button type="button" class="btn btn-secondary"
                                                                        data-bs-dismiss="modal">Close</button>
                                                                    <button class="btn btn-danger"
                                                                        type="submit">Delete</button>
                                                                </div>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
