@extends('admin.layouts.master')

@push('css')
    <!-- Datatables CSS -->
    <link rel="stylesheet" href="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.css' }}">
    <style>
        .bg-confirmed {
            color: green;
            background: rgba(0, 255, 0, 0.3);
        }

        .bg-completed {
            color: purple;
            background: #80008020;
        }

        .bg-pending {
            color: orangered;
            background: rgba(255, 165, 0, 0.3);
        }

        .bg-canceled {
            color: red;
            background: rgba(255, 0, 0, 0.2);
        }

        .bg-rejected {
            color: #555;
            background: #55555520;
        }
    </style>
@endpush

@push('js')
    <!-- Datatables JS -->
    <script src="{{ asset('ad') . '/assets/plugins/datatables/jquery.dataTables.min.js' }}"></script>
    <script src="{{ asset('ad') . '/assets/plugins/datatables/datatables.min.js' }}"></script>
    <script>
        setActiveMenuItem('reservations');
    </script>
@endpush

@section('content')
    <!-- Page Header -->
    <div class="page-header">
        <div class="row">
            <div class="col">
                <h3 class="page-title">Reservations</h3>
                <ul class="breadcrumb">
                    <li class="breadcrumb-item"><a href="index.html">Dashboard</a></li>
                    <li class="breadcrumb-item active">Reservations</li>
                </ul>
            </div>
        </div>
    </div>
    <!-- /Page Header -->

    <div class="row">
        <div class="col-sm-12">

            <div class="card card-table">
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-center table-hover datatable">
                            <thead class="thead-light">
                                <tr>
                                    <th data-searchable="true">Order ID</th>
                                    <th data-searchable="true">Property</th>
                                    <th data-searchable="true">Client</th>
                                    <th data-searchable="true">Email</th>
                                    <th data-searchable="true">Phone</th>
                                    <th data-filterselect="true">Status</th>
                                    <th data-searchable="true">Arrival</th>
                                    <th data-searchable="true">Departure</th>
                                    <th data-searchable="true">Period</th>
                                    <th data-searchable="true">Total</th>
                                    <th>Client Notes</th>
                                    <th data-searchable="true">Reserved At</th>
                                    <th class="text-end">Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($reservations as $reservation)
                                    <tr>
                                        <td>#{{ $reservation->order_id }}</td>
                                        <td><a href="{{ route('admin.cars.preview', ['car' => $reservation->car->id]) }}"
                                                target="_blank">{{ $reservation->car->title }}</a></td>
                                        @if ($reservation->user)
                                            <td title="Registered User"><i data-feather="award" class="text-success"></i>
                                                {{ $reservation->user->firstname . ' ' . $reservation->user->laststname }}
                                            </td>
                                            <td><a
                                                    href="mailto:{{ $reservation->user->email }}">{{ $reservation->user->email }}</a>
                                            </td>
                                            <td>{{ $reservation->user->phone }}</td>
                                        @else
                                            <td>{{ $reservation->firstname . ' ' . $reservation->laststname }}
                                            </td>
                                            <td><a href="mailto:{{ $reservation->email }}">{{ $reservation->email }}</a>
                                            </td>
                                            <td>{{ $reservation->phone }}</td>
                                        @endif
                                        <td>
                                            <span
                                                class="badge badge-pill bg-{{ $reservation->status }}">{{ $reservation->status }}</span>
                                        </td>
                                        <td>{{ $reservation->arrival->format('d-m-Y H:i') }}</td>
                                        <td>{{ $reservation->departure->format('d-m-Y H:i') }}</td>
                                        <td>
                                            @php
                                                $interval = $reservation->arrival->diff($reservation->departure);

                                                $totalDays = $interval->days;

                                                $months = intdiv($totalDays, 30);
                                                $remainingDays = $totalDays % 30;

                                                echo ($months > 0 ? $months . ' months' : '') . ($remainingDays > 0 ? ($months > 0 ? ', ' : '') . $remainingDays . ' days' : '');
                                            @endphp
                                        </td>
                                        <td>{{ $reservation->total . ' ' . $reservation->currency->symbol }}</td>
                                        <td>{{ $reservation->comment }}</td>
                                        <td>{{ $reservation->created_at->format('d-m-Y H:i') }}</td>
                                        <td class="text-end">
                                            <button class="btn btn-sm btn-white text-success me-2" data-bs-toggle="modal"
                                                data-bs-target="#modal{{ $reservation->id }}"><i
                                                    class="far fa-edit me-1"></i> Edit</button>
                                            <div class="modal fade" id="modal{{ $reservation->id }}"
                                                data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
                                                aria-labelledby="modal{{ $reservation->id }}Label" aria-hidden="true">
                                                <div class="modal-dialog">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title" id="modal{{ $reservation->id }}Label">
                                                                Edit Reservation</h5>
                                                            <button type="button" class="btn-close" data-bs-dismiss="modal"
                                                                aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body text-start">
                                                            <form class="ajax-form px-3 row"
                                                                action="{{ route('admin.reservations.update', ['reservation' => $reservation->id]) }}"
                                                                method="POST">
                                                                @csrf
                                                                @method('PUT')

                                                                <div class="mb-3 col-md-12 col-sm-12">
                                                                    <label for="name" class="form-label">Status</label>
                                                                    <select class="form-control form-select" name="status"
                                                                        required="">
                                                                        <option value="confirmed"
                                                                            {{ $reservation->status == 'confirmed' ? 'selected' : '' }}>
                                                                            confirmed</option>
                                                                        <option value="completed"
                                                                            {{ $reservation->status == 'completed' ? 'selected' : '' }}>
                                                                            completed</option>
                                                                        <option value="pending"
                                                                            {{ $reservation->status == 'pending' ? 'selected' : '' }}>
                                                                            pending</option>
                                                                        <option value="canceled"
                                                                            {{ $reservation->status == 'canceled' ? 'selected' : '' }}>
                                                                            canceled</option>
                                                                        <option value="rejected"
                                                                            {{ $reservation->status == 'rejected' ? 'selected' : '' }}>
                                                                            rejected</option>
                                                                    </select>
                                                                </div>

                                                                <div class="mt-3 text-end">
                                                                    <button type="button" class="btn btn-secondary"
                                                                        data-bs-dismiss="modal">Close</button>
                                                                    <button class="btn btn-primary"
                                                                        type="submit">Save</button>
                                                                </div>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <button class="btn btn-sm btn-white text-danger me-2" data-bs-toggle="modal"
                                                data-bs-target="#dmodal{{ $reservation->id }}"><i
                                                    class="far fa-trash-alt me-1"></i>Delete</button>
                                            <div class="modal fade" id="dmodal{{ $reservation->id }}"
                                                data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
                                                aria-labelledby="dmodal{{ $reservation->id }}Label" aria-hidden="true">
                                                <div class="modal-dialog">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title" id="dmodal{{ $reservation->id }}Label">
                                                                Confirm Deletion</h5>
                                                            <button type="button" class="btn-close" data-bs-dismiss="modal"
                                                                aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body text-start">
                                                            <form class="ajax-form px-3"
                                                                action="{{ route('admin.reservations.destroy', ['reservation' => $reservation->id]) }}"
                                                                method="POST">
                                                                @csrf
                                                                @method('DELETE')
                                                                <div class="mb-3">
                                                                    <label for="name" class="form-label">Name</label>
                                                                    <input class="form-control" disabled type="text"
                                                                        name="name"
                                                                        value="#{{ $reservation->order_id }}"
                                                                        required=""
                                                                        placeholder="type reservation name ..">
                                                                </div>

                                                                <div class="mt-3 text-end">
                                                                    <button type="button" class="btn btn-secondary"
                                                                        data-bs-dismiss="modal">Close</button>
                                                                    <button class="btn btn-danger"
                                                                        type="submit">Delete</button>
                                                                </div>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
